==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/config_wizard/translations/config_wizard_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu needs to be restarted before changes to the language settings will take effect.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Account Setup&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>IM Network</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>I want to set up existing account for Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>I want to create new account for Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>I don&apos;t want to set up my account for Kadu now</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Go to Accounts Setting after closing this window</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Start Configuration Wizard</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Profile setup&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Language</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nickname</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Account Setup&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kadu Wizard</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/config_wizard/translations/config_wizard_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu needs to be restarted before changes to the language settings will take effect.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardActions</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation type="unfinished">Start Configuration Wizard</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Account Setup&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>IM Network</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>I want to set up existing account for Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>I want to create new account for Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>I don&apos;t want to set up my account for Kadu now</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Go to Accounts Setting after closing this window</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Profile setup&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Language</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nickname</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Account Setup&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kadu Wizard</translation>
    </message>
</context>
</TS>
